
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : general.scm
;; DESCRIPTION : general scheme routines for TeXmacs
;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
;;
;; This software falls under the GNU general public license and comes WITHOUT
;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; General commands
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (setup-printer cmd type dpi)
  (set-printing-command cmd)
  (set-printer-page-type type)
  (set-printer-dpi dpi))

(define (preview-with-ghostview)
  (print-to-file "$TEXMACS_HOME_PATH/system/preview.ps")
  (cond ((file-exists? "$PATH" "ghostview")
	 (shell "ghostview $TEXMACS_HOME_PATH/system/preview.ps &"))
	((file-exists? "$PATH" "gv")
	 (shell "gv $TEXMACS_HOME_PATH/system/preview.ps &"))
	(else (set-message
	       "Error: ghostview does not seem to be installed on your system"
	       "preview"))))

(define (choose-file-and-print-page-selection start end)
  (choose-file "Print page selection to file" "postscript"
	       `(lambda (name) (print-pages-to-file name ,start ,end))))

(define (load-texmacs-buffer s) (load-buffer s "TeXmacs"))
(define (save-texmacs-buffer s) (save-buffer s "TeXmacs"))
(define (load-latex-buffer s) (load-buffer s "latex"))
(define (save-latex-buffer s) (save-buffer s "latex"))
(define (load-html-buffer s) (load-buffer s "html"))
(define (save-html-buffer s) (save-buffer s "html"))
(define (load-scheme-buffer s) (load-buffer s "scheme"))
(define (save-scheme-buffer s) (save-buffer s "scheme"))
(define (load-verbatim-buffer s) (load-buffer s "verbatim"))
(define (save-verbatim-buffer s) (save-buffer s "verbatim"))
(define (load-help-buffer s) (load-buffer s "help"))
(define (load-in-new-window s) (load-generic-buffer-into s 1))

(define (get-env s)
  (tree->string (get-env-tree s)))

(define (quit-TeXmacs-modulo-checks)
  (if (exists-unsaved-buffer?)
      (interactive
       '("There are unsaved files. Really quit?")
       'quit-TeXmacs-confirm)
      (quit-TeXmacs)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Initialization commands
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (init-page-margins l r t b)
  (init-env "odd page margin" l)
  (init-env "even page margin" l)
  (init-env "page right margin" r)
  (init-env "page top margin" t)
  (init-env "page bottom margin" b))

(define (init-screen-reduction l r t b)
  (init-env "reduction page left margin" l)
  (init-env "reduction page right margin" r)
  (init-env "reduction page top margin" t)
  (init-env "reduction page bottom margin" b))

(define (init-page-size w h p)
  (init-env "page type" "user")
  (init-env "page width" w)
  (init-env "page height" h)
  (init-env "paragraph width" p)
  (init-page-margins "5mm" "5mm" "5mm" "5mm")
  (init-screen-reduction "0cm" "0cm" "0cm" "0cm"))

(define (init-text-width s) (init-env "paragraph width" s))
(define (init-font-size s) (init-env "font base size" s))
(define (init-dpi s) (init-env "dpi" s))
(define (init-first-indent s) (init-env "first indentation" s))
(define (init-interline s) (init-env "interline space" s))
(define (init-par-spc s) (init-env "interparagraph space" s))
(define (init-magn s) (init-env "magnification" s))
(define (other-shrinking-factor s) (set-shrinking-factor (string->number s)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Miscellaneous commands
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (real-math-font? fn)
  (or (equal? fn "roman") (equal? fn "concrete")))

(define (real-math-family? fn)
  (or (equal? fn "mr") (equal? fn "ms") (equal? fn "mt")))

(define (prog-remove-backwards)
  (if (inside? "input") (session-remove-backwards) (remove-backwards)))

(define (filter-maxima-in session s)
  (cond ((equal? s "") "0;")
	((equal? (car (reverse (string->list s))) #\;) s)
	((equal? (car (reverse (string->list s))) #\$) s)
	(else (string-append s ";"))))

(define (extern-exec s)
  (if (inside? "session")
      (connection-exec (get-env "prog language") (get-env "this session") s)))
