
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : keymaps.scm
;; DESCRIPTION : setup key combinations for frequently used commands
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public license and comes WITHOUT
;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(set-shorthands '(text math prog)
  '(("E-e" "" "Insert executable markup")
    ("E-i" "" "Insert inactive markup")
    ("E-s" "" "Insert structural markup")
    ("E-1" "" "Operation on primary selection")
    ("E-2" "" "Operation on secondary selection")
    ("E-3" "" "Operation on ternary selection")
    ("E-0" "" "Operation on named selection")))

(set-keymap '(text math prog)
  '(("S-space" (insert-string " "))
    ("return" (cond ((is-deactivated?) (activate))
		    ((inside-section?)
		     (go-end-line)
		     (insert-return))
		    ((inside? "item*")
		     (go-end-of "item*"))
		    ((inside? "equation")
		     (go-end-of "equation")
		     (insert-return))
		    ((inside? "equation*")
		     (go-end-of "equation*")
		     (insert-return))
		    ((inside? "eqnarray*")
		     (make-format "next line")
		     (make-equation))
		    (else (insert-return))))
    ("S-return" (insert-return))
    ("backspace" (remove-backwards))
    ("delete" (remove-backwards))
    ("S-backspace" (remove-backwards))
    ("S-delete" (remove-backwards))
    ("C-backspace" (remove-structure-backwards))
    ("E-backspace" (remove-structure-upwards))
    ("left" (go-left))
    ("right" (go-right))
    ("up" (go-up))
    ("down" (go-down))
    ("pagedown" (go-page-down))
    ("pageup" (go-page-up))
    ("home" (go-start-line))
    ("end" (go-end-line))
    ("S-home" (go-start))
    ("S-end" (go-end))
    ("C-home"
      (begin
	(selection-set-start)
	(select-from-keyboard #t)))
    ("C-end"
      (begin
	(selection-set-end)
	(select-from-keyboard #f)))
    ("A-space" (make-space "0.2spc"))
    ("A-backspace" (make-space "-0.2spc"))
    ("tab" (if (or (is-deactivated?) (in-preamble-mode?) (xml-inside-attr?))
               (insert-argument) (make-htab "5mm")))
    ("cut" (cut "primary"))
    ("paste" (paste "primary"))
    ("copy" (copy "primary"))
    ("undo" (undo))
    ("redo" (redo))
    ("cancel" (selection-clear "primary"))

    ("F1" (load-help-buffer "help/welcome"))
    ("F2" (choose-file "Load file" "" 'load-generic-buffer))
    ("S-F2" (choose-file "Load file" "" 'load-in-new-window))
    ("C-F2" (revert-buffer))
    ("E-F2" (new-buffer))
    ("E-S-F2" (open-window))
    ("E-C-F2" (clone-window))
    ("F3" (save-texmacs-buffer (get-name-buffer)))
    ("S-F3" (choose-file "Save TeXmacs file" "TeXmacs" 'save-texmacs-buffer))
    ("F4" (print))
    ("S-F4" (interactive '("File name:") 'print-to-file))
    ("C-F4" (begin (print-to-file "$TEXMACS_HOME_PATH/system/preview.ps")
		   (shell "ghostview $TEXMACS_HOME_PATH/system/preview.ps &")))
    ("E-F4" (interactive '("First page:" "Last page:") 'print-pages))
    ("E-S-F4" (interactive
	       '("File name:" "First page:" "Last page:")
	       'print-pages-to-file))
    ("E-C-F4" (interactive
	       '("Printing command:" "Paper type:" "Printer dpi:")
	       'setup-printer))
    ("F5" (copy "primary"))
    ("S-F5" (paste "primary"))
    ("C-F5" (selection-clear "primary"))
    ("E-F5" (interactive '("Copy to:") 'copy))
    ("E-S-F5" (interactive '("Paste from:") 'paste))
    ("E-C-F5" (interactive '("Clear selection:") 'selection-clear))
    ("F6" (copy "secondary"))
    ("S-F6" (paste "secondary"))
    ("C-F6" (selection-clear "secondary"))
    ("E-F6" (copy "ternary"))
    ("E-S-F6" (paste "ternary"))
    ("E-C-F6" (selection-clear "ternary"))
    ("F12" (xml-toggle))

    ("\\" (make-inactive-hybrid))
    ("E-&" (make-format "line separator"))
    ("E-:" (make-format "line break"))
    ("E-;" (make-format "new line"))
    ("E-return" (make-format "next line"))
    ("E-/" (make-format "no line break"))
    ("E-[" (undo))
    ("E-]" (redo))
    ("E-<" (go-start))
    ("E->" (go-end))
    ("E-$" (spell-start))
    ("E-*" (interactive '("Command:") 'TeXmacs-eval))
    ("E-=" (make-inactive-assign))
    ("E-w" (make-inactive-with))
    ("E-m" (make-inactive-macro))
    ("E-f" (make-inactive-function))
    ("E-!" (make-inactive-label))
    ("E-?" (make-inactive-reference))
    ("E-c" (copy "primary"))
    ("E-p" (paste "primary"))
    ("E-x" (cut "primary"))
    ("E-r" (selection-clear "primary"))

    ("E-1 c" (copy "primary"))
    ("E-1 p" (paste "primary"))
    ("E-1 x" (cut "primary"))
    ("E-1 r" (selection-clear "primary"))
    ("E-2 c" (copy "secondary"))
    ("E-2 p" (paste "secondary"))
    ("E-2 x" (cut "secondary"))
    ("E-2 r" (selection-clear "secondary"))
    ("E-3 c" (copy "ternary"))
    ("E-3 p" (paste "ternary"))
    ("E-3 x" (cut "ternary"))
    ("E-3 r" (selection-clear "ternary"))
    ("E-0 c" (interactive '("Copy to:") 'copy))
    ("E-0 p" (interactive '("Paste from:") 'paste))
    ("E-0 x" (interactive '("Cut to:") 'cut))
    ("E-0 r" (interactive '("Clear selection:") 'selection-clear))

    ("E-i #" (make-inactive-argument))
    ("E-i s" (make-inactive-symbol))
    ("E-i l" (make-inactive-latex))
    ("E-i e" (make-inactive-expand))
    ("E-i a" (make-inactive-apply))
    ("E-i v" (make-inactive-value))
    ("E-i h" (make-inactive-hold))
    ("E-i r" (make-inactive-release))
    ("E-i g" (make-inactive-group))
    ("E-i q" (make-inactive-quote))
    ("E-i d" (make-inactive-delay))
    ("E-i *" (make-inactive-action))
    ("E-i >" (make-inactive-hyperlink))
    ("E-i w" (make-inactive-write))
    ("E-i s" (make-inactive-surround))
    ("E-i t" (make-inactive-tag))
    ("E-i m" (make-inactive-meaning))
    ("E-i x" (make-big-xml))

    ("E-e x" (make-inactive-eval))
    ("E-e |" (make-inactive-or))
    ("E-e ^" (make-inactive-xor))
    ("E-e &" (make-inactive-and))
    ("E-e !" (make-inactive-not))
    ("E-e +" (make-inactive-plus))
    ("E-e -" (make-inactive-minus))
    ("E-e *" (make-inactive-times))
    ("E-e /" (make-inactive-over))
    ("E-e d" (make-inactive-div))
    ("E-e m" (make-inactive-mod))
    ("E-e ;" (make-inactive-merge))
    ("E-e l" (make-inactive-length))
    ("E-e #" (make-inactive-number))
    ("E-e @" (make-date))
    ("E-e E-@" (make-inactive-date))
    ("E-e t" (make-inactive-translate))
    ("E-e =" (make-inactive-equal))
    ("E-e E-=" (make-inactive-unequal))
    ("E-e <" (make-inactive-less))
    ("E-e E-<" (make-inactive-lesseq))
    ("E-e >" (make-inactive-greater))
    ("E-e E->" (make-inactive-greatereq))
    ("E-e ?" (make-inactive-if))
    ("E-e i" (make-inactive-if))
    ("E-e c" (make-inactive-case))
    ("E-e w" (make-inactive-while))
    ;; ("E-e e" (make-inactive-extern))
    ;; ("E-e a" (make-inactive-authorize))

    ("E-s s" (make-expand-arg "strong"))
    ("E-s t" (make-expand-arg "tt"))
    ("E-s e" (make-expand-arg "em"))
    ("E-s n" (make-expand-arg "name"))
    ("E-s p" (make-expand-arg "samp"))

    ("E-left"
      (if (inside-tree?) (branch-insert #f) (column-insert #f)))
    ("E-right"
      (if (inside-tree?) (branch-insert #t) (column-insert #t)))
    ("E-up" (row-insert #f))
    ("E-down" (row-insert #t))
    ("S-left"
      (if (inside-tree?) (branch-insert #f) (column-insert #f)))
    ("S-right"
      (if (inside-tree?) (branch-insert #t) (column-insert #t)))
    ("S-up" (row-insert #f))
    ("S-down" (row-insert #t))
    ("C-left" (mosaic-horizontal "<"))
    ("C-right" (mosaic-horizontal ">"))
    ("C-up" (mosaic-vertical "<"))
    ("C-down" (mosaic-vertical ">"))
    ("A-right" (mosaic-glue "r"))
    ("A-down" (mosaic-glue "d"))

    ("E-E-\\" (insert-string "\\"))
    ("E-E-$" (insert-string "$"))
    ("E-E-&" (insert-string "&"))
    ("E-E-#" (insert-string "#"))
    ("E-E-" (insert-string ""))
    ("E-E-%" (insert-string "%"))))

(set-keymap '(text)
  '(("$" (make-with "mode" "math"))
    ("E-I" (make-list "itemize"))
    ("E-E" (make-list "enumerate"))
    ("E-D" (make-list "description"))
    ("E-N" (make-item))
    ("E-S" (make-session "scheme"))

    ("E-C-s" (make-with "font family" "ss"))
    ("E-C-t" (make-with "font family" "tt"))
    ("E-C-b" (make-with "font series" "bold"))
    ("E-C-m" (make-with "font series" "medium"))
    ("E-C-r" (make-with "font shape" "right"))
    ("E-C-i" (make-with "font shape" "italic"))
    ("E-C-l" (make-with "font shape" "slanted"))
    ("E-C-p" (make-with "font shape" "small-caps"))))

(set-keymap '(math)
  '(("$" (go-end-with "mode" "math"))
    ("E-$" (make-with "mode" "text"))
    ("_" (make-script #f #t))
    ("^" (make-script #t #t))
    ("circumflex" (make-script #t #t))
    ("`" (make-lprime "`"))
    ("'" (make-rprime "'"))
    ("acute" (make-lprime "`"))
    ("grave" (make-rprime "'"))
    ("A-'" (make-rprime "<dag>"))
    ("A-acute" (make-rprime "<dag>"))
    ("E-~" (make-wide "~"))
    ("E-^" (make-wide "^"))
    ("E-B" (make-wide "<bar>"))
    ("E-V" (make-wide "<vect>"))
    ("E-C" (make-wide "<check>"))
    ("E-U" (make-wide "<breve>"))
    ("E-'" (make-wide "<acute>"))
    ("E-`" (make-wide "<grave>"))
    ("E-." (make-wide "<dot>"))
    ("E-\"" (make-wide "<ddot>"))
    ("E-tilde" (make-wide "~"))
    ("E-circumflex" (make-wide "^"))
    ("E-acute" (make-wide "<acute>"))
    ("E-grave" (make-wide "<grave>"))
    ("abovedot" (make-wide "<dot>"))
    ("umlaut" (make-wide "<ddot>"))
    ("E-L _" (make-script #f #f))
    ("E-L ^" (make-script #t #f))
    ("E-L circumflex" (make-script #t #f))
    ("E-F" (make-fraction))
    ("E-S" (make-sqrt))
    ("E-R" (make-var-sqrt))
    ("E-N" (make-neg))
    ("E-A" (make-tree))
    ("E-M" (make-matrix))
    ("E-T" (make-table))

    ("E-C-R" (make-with "math font" "roman"))
    ("E-C-K" (make-with "math font" "concrete"))
    ("E-C-F" (make-with "math font" "Euler"))
    ("E-C-E" (make-with "math font" "ENR"))
    ("E-C-C" (make-with "math font" "cal"))
    ("E-C-B" (make-with "math font" "Bbb*"))
    ("E-C-o" (make-with "math font family" "mr"))
    ("E-C-s" (make-with "math font family" "ms"))
    ("E-C-t" (make-with "math font family" "mt"))
    ("E-C-m" (make-with "math font series" "medium"))
    ("E-C-b" (make-with "math font series" "bold"))
    ("E-C-n" (make-with "math font shape" "normal"))
    ("E-C-r" (make-with "math font shape" "right"))
    ("E-C-l" (make-with "math font shape" "slanted"))
    ("E-C-i" (make-with "math font shape" "italic"))
    ("E-C-u" (make-with "math font shape" "semi-right"))

    ("E-E-S" (make-big-operator "sum"))
    ("E-E-P" (make-big-operator "prod"))
    ("E-E-I" (make-big-operator "int"))
    ("E-E-O" (make-big-operator "oint"))
    ("E-E-A" (make-big-operator "amalg"))
    ("E-E-N" (make-big-operator "cap"))
    ("E-E-W" (make-big-operator "wedge"))
    ("E-E-U" (make-big-operator "cup"))
    ("E-E-V" (make-big-operator "vee"))
    ("E-E-@ ." (make-big-operator "odot"))
    ("E-E-@ +" (make-big-operator "oplus"))
    ("E-E-@ x" (make-big-operator "otimes"))

    ("E-E-(" (make-large-left "("))
    ("E-E-)" (make-large-right ")"))
    ("E-E-[" (make-large-left "["))
    ("E-E-]" (make-large-right "]"))
    ("E-E-{" (make-large-left "{"))
    ("E-E-}" (make-large-right "}"))
    ("E-E-<" (make-large-left "langle"))
    ("E-E->" (make-large-right "rangle"))
    ("E-E-/" (make-large-middle "/"))
    ("E-E-b" (make-large-middle "\\"))
    ("E-E-|" (make-large-middle "|"))

    ("E-E-l (" (make-large-left "("))
    ("E-E-l )" (make-large-left ")"))
    ("E-E-l [" (make-large-left "["))
    ("E-E-l ]" (make-large-left "]"))
    ("E-E-l {" (make-large-left "{"))
    ("E-E-l }" (make-large-left "}"))
    ("E-E-l <" (make-large-left "langle"))
    ("E-E-l >" (make-large-left "rangle"))
    ("E-E-l /" (make-large-left "/"))
    ("E-E-l b" (make-large-left "\\"))
    ("E-E-l |" (make-large-left "|"))

    ("E-E-m (" (make-large-middle "("))
    ("E-E-m )" (make-large-middle ")"))
    ("E-E-m [" (make-large-middle "["))
    ("E-E-m ]" (make-large-middle "]"))
    ("E-E-m {" (make-large-middle "{"))
    ("E-E-m }" (make-large-middle "}"))
    ("E-E-m <" (make-large-middle "langle"))
    ("E-E-m >" (make-large-middle "rangle"))
    ("E-E-m /" (make-large-middle "/"))
    ("E-E-m b" (make-large-middle "\\"))
    ("E-E-m |" (make-large-middle "|"))

    ("E-E-r (" (make-large-right "("))
    ("E-E-r )" (make-large-right ")"))
    ("E-E-r [" (make-large-right "["))
    ("E-E-r ]" (make-large-right "]"))
    ("E-E-r {" (make-large-right "{"))
    ("E-E-r }" (make-large-right "}"))
    ("E-E-r <" (make-large-right "langle"))
    ("E-E-r >" (make-large-right "rangle"))
    ("E-E-r /" (make-large-right "/"))
    ("E-E-r b" (make-large-right "\\"))
    ("E-E-r |" (make-large-right "|"))))

(set-keymap '(prog)
  '(("<" (insert-string "<less>"))
    (">" (insert-string "<gtr>"))
    ("left" (if (inside? "input") (session-go-left) (go-left)))
    ("right" (if (inside? "input") (session-go-right) (go-right)))
    ("up" (if (inside? "input") (session-go-up) (go-up)))
    ("down" (if (inside? "input") (session-go-down) (go-down)))
    ("pageup" (if (inside? "input") (session-go-page-up) (go-page-up)))
    ("pagedown" (if (inside? "input") (session-go-page-down) (go-page-down)))
    ("return" (if (inside? "input") (process-input) (insert-return)))
    ("backspace" (prog-remove-backwards))
    ("delete" (prog-remove-backwards))
    ("S-backspace" (prog-remove-backwards))
    ("S-delete" (prog-remove-backwards))))

(set-keymap '(russian)
  '(("modeswitch" (begin
		    (make-with "language" "english")
		    (make-with "font" "roman")))))
