
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : icon-menu.scm
;; DESCRIPTION : the default icon menus of TeXmacs
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public license and comes WITHOUT
;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define texmacs-main-icons
  '((=> (balloon (icon "tm_new.xpm") "Open a new buffer")
	("new buffer" "E-F2" (new-buffer))
	("open new window" "E-S-F2" (open-window))
	("clone window" "E-C-F2" (clone-window)))
    (=> (balloon (icon "tm_open.xpm") "Load a file")
	("load buffer" "F2" (choose-file "Load file" "" 'load-generic-buffer))
	("revert buffer" "C-F2" (revert-buffer))
	("load in new window" "S-F2"
	 (choose-file "Load file" "" 'load-in-new-window))
	---
	("import#verbatim"
	  (choose-file "Load verbatim file" "" 'load-verbatim-buffer))
	("import#html"
          (choose-file "Load html file" "html" 'load-html-buffer))
	("import#LaTeX"
          (choose-file "Load LaTeX file" "latex" 'load-latex-buffer))
	("import#scheme"
          (choose-file "Load scheme file" "scheme" 'load-scheme-buffer)))
    (=> (balloon (icon "tm_save.xpm") "Save this buffer")
	("save buffer" "F3" (save-texmacs-buffer (get-name-buffer)))
	("save buffer as" "S-F3"
	 (choose-file "Save TeXmacs file" "TeXmacs" 'save-texmacs-buffer))
	---
	("export as#verbatim"
	  (choose-file "Save verbatim file" "" 'save-verbatim-buffer))
	("export as#LaTeX"
	  (choose-file "Save LaTeX file" "latex" 'save-latex-buffer))
	("export as#scheme"
	  (choose-file "Save scheme file" "scheme" 'save-scheme-buffer))
	("export as#postscript"
	  (choose-file "File postscript file" "postscript"
		       'export-postscript)))
    (=> (balloon (icon "tm_print.xpm") "Print") (link print-menu))
    (=> (balloon (icon "tm_style.xpm") "Select a document style")
	("no style" (init-style "none"))
	---
	(link style-menu)
	---
	("other style" (interactive '("Document style:") 'init-style)))
    (=> (balloon (icon "tm_language.xpm") "Select a language")
	;;("czech"
	;;(begin
	;;(init-env "language" "czech")
	;;(set-output-language "czech")))
	("dutch"
	  (begin
	    (init-env "language" "dutch")
	    (set-output-language "dutch")))
	("english"
	  (begin
	    (init-env "language" "english")
	    (set-output-language "english")))
	("french"
	  (begin
	    (init-env "language" "french")
	    (set-output-language "french")))
	("german"
	  (begin
	    (init-env "language" "german")
	    (set-output-language "german")))
	("polish"
	  (begin
	    (init-env "language" "polish")
	    (set-output-language "polish")))
	("romanian"
	  (begin
	    (init-env "language" "romanian")
	    (set-output-language "romanian")))
	("russian"
	  (begin
	    (init-env "language" "russian")
	    (init-env "font" "cyrillic")
	    (set-output-language "russian")))
	("spanish"
	  (begin
	    (init-env "language" "spanish")
	    (set-output-language "spanish")))
	("swedish"
	  (begin
	    (init-env "language" "swedish")
	    (set-output-language "swedish"))))
    (=> (balloon (icon "tm_cancel.xpm") "Close")
	("close buffer" "C-x k" (kill-buffer))
	("close window" "" (kill-window))
	("close TeXmacs" "C-x C-c" (quit-TeXmacs-modulo-checks)))
    |
    ((balloon (icon "tm_cut.xpm") "Cut text#(E-x)") (cut "primary"))
    ((balloon (icon "tm_copy.xpm") "Copy text#(E-c)") (copy "primary"))
    ((balloon (icon "tm_paste.xpm") "Paste text#(E-p)") (paste "primary"))
    (if (not (in-search-mode?))
	((balloon (icon "tm_find.xpm") "Find text#(C-s)") (search-start #t)))
    (if (in-search-mode?)
	((balloon (icon "tm_find_next.xpm") "Find next match#(C-s)")
	  (search-button-next)))
    ((balloon (icon "tm_replace.xpm") "Query replace#(C-=)")
      (interactive '("Replace:" "Replace by:") 'replace-start-forward))
    ((balloon (icon "tm_spell.xpm") "Check text for spelling errors#(E-$)")
      (spell-start))
    ((balloon (icon "tm_undo.xpm") "Undo last changes#(E-[)") (undo))
    ((balloon (icon "tm_redo.xpm") "Redo undone changes#(E-])") (redo))
    |
    (=> (balloon (icon "tm_math.xpm") "Insert mathematics")
	(if (not (equal? (get-env "mode") "math"))
	    ("formula" "$" (make-with "mode" "math"))
	    (if (style-has? "basic-style")
		("equation" (make-big-expand "equation*"))
		("equations"
		 (begin (make-big-expand "eqnarray*") (make-equation)))
		("numbered equation" (make-big-expand "equation"))))
	(if (equal? (get-env "mode") "math")
	    ("text" "E-$" (make-with "mode" "text"))
	    (if (inside? "eqnarray*")
		("equation" (begin
			      (make-format "next line")
			      (make-equation))))))
    (=> (balloon (icon "tm_table.xpm") "Insert a table or a matrix")
	(link mosaic-menu))
    ((balloon (icon "tm_image.xpm") "Insert a picture")
      (choose-file "Load image" "image" 'make-image))
    (=> (balloon (icon "tm_link.xpm") "Insert a link")
	("label" "E-!" (make-inactive-label))
	("reference" "E-?" (make-inactive-reference))
	("hyperlink" "E-i >" (make-inactive-hyperlink))
	("action" "E-i *" (make-inactive-action))
	("citation" (make-inactive-apply-arg "cite"))
	("invisible citation" (make-inactive-apply-arg "nocite")))
    (if (style-has? "program-style")
	(=> (balloon (icon "tm_shell.xpm")
		     "Start an interactive session")
	    (link session-menu)
	    ---
	    ("other" (interactive
              '("Session type:" "Session name:") 'make-session))))))

(define texmacs-text-icons
  '((if (style-has? "book-style")
	(=> (balloon (icon "tm_chapter.xpm") "Start a new chapter")
	    ("chapter" (make-section-arg "chapter"))
	    ("appendix" (make-section-arg "appendix"))
	    ("prologue" (make-section "prologue"))
	    ("epilogue" (make-section "epilogue"))))
    (if (style-has? "maketitle")
	(=> (balloon (icon "tm_title.xpm") "Enter a title")
	    ("title" (make-inactive-apply-arg "title"))
	    ("author" (make-inactive-apply-arg "author"))
	    ("address" (make-inactive-apply-arg "address"))
	    ("make title" (make-section "maketitle"))
	    ---
	    ("abstract" (make-big-expand "abstract"))))
    (if (style-has? "section")
	(=> (balloon (icon "tm_section.xpm") "Start a new section")
	    ("section" (make-section-arg "section"))
	    ("subsection" (make-section-arg "subsection"))
	    ("subsubsection" (make-section-arg "subsubsection"))
	    (if (style-has? "paragraph")
		---
		("paragraph" (make-section-arg "paragraph"))
		("subparagraph" (make-section-arg "subparagraph")))))
    (if (style-has? "basic-style")
	(=> (balloon (icon "tm_theorem.xpm") "Insert an environment")
	    (if (style-has? "theorem-style")
		("theorem" (make-big-expand "theorem"))
		("proposition" (make-big-expand "proposition"))
		("lemma" (make-big-expand "lemma"))
		("corollary" (make-big-expand "corollary"))
		("proof" (make-big-expand "proof"))
		("axiom" (make-big-expand "axiom"))
		("definition" (make-big-expand "definition"))
		---
		("remark" (make-big-expand "remark"))
		("note" (make-big-expand "note"))
		("example" (make-big-expand "example"))
		("exercise" (make-big-expand "exercise"))
		("warning" (make-big-expand "warning"))
		---)
	    ("verbatim" (make-big-expand "verbatim"))
	    ("code" (make-big-expand "code"))
	    ("quote" (make-big-expand "quote"))
	    ("quotation" (make-big-expand "quotation"))
	    ("verse" (make-big-expand "verse"))))
;;  ((balloon (icon "tm_footnote.xpm") "Insert a footnote") ())
;;  ((balloon (icon "tm_margin.xpm") "Insert a marginal note") ())
;;  ((balloon (icon "tm_floating.xpm") "Insert a floating object") ())
;;  ((balloon (icon "tm_multicol.xpm") "Start multicolumn context") ())
    (=> (balloon (icon "tm_parstyle.xpm") "Set paragraph mode")
	((balloon (icon "tm_left.xpm") "Align text to the left")
	 (make-line-with "paragraph mode" "left"))
	((balloon (icon "tm_center.xpm") "Center text")
	 (make-line-with "paragraph mode" "center"))
	((balloon (icon "tm_right.xpm") "Align text to the right")
	 (make-line-with "paragraph mode" "right"))
	((balloon (icon "tm_justify.xpm") "Justify text")
	 (make-line-with "paragraph mode" "justify")))
    (=> (balloon (icon "tm_parindent.xpm") "Set paragraph margins")
	("left margin" (interactive '("Left margin:") 'set-left-margin))
	("right margin" (interactive '("Right margin:") 'set-right-margin))
	("first indentation"
	 (interactive '("First indentation:") 'set-first-indent)))
    (if (style-has? "automatic-style")
	(=> (balloon (icon "tm_index.xpm")
		     "Insert automatically generated content")
	    ("table of contents" (make-aux "table-of-contents" "toc"))
	    ("bibliography" (interactive
	      '("Bibliography style:" "Bibliography file:") 'make-bib))
	    ("index" (make-aux "index" "idx"))
	    ("glossary" (make-aux "glossary" "gly"))
	    ("list of figures" (make-aux "list-of-figures" "lof"))
	    ("list of tables" (make-aux "list-of-tables" "lot"))))
    |
    (if (style-has? "list-style")
	(=> (balloon (icon "tm_itemize.xpm") "Itemize")
	    ("default" "E-I" (make-list "itemize"))
	    ---
	    ("minus" (make-list "itemize-minus"))
	    ("dot" (make-list "itemize-dot"))
	    ("arrow" (make-list "itemize-arrow")))
	(=> (balloon (icon "tm_enumerate.xpm") "Enumerate")
	    ("default" "E-E" (make-list "enumerate"))
	    ---
	    ("1, 2, 3, ..." (make-list "enumerate-numeric"))
	    ("i, ii, iii, ..." (make-list "enumerate-roman"))
	    ("I, II, III, ..." (make-list "enumerate-Roman"))
	    ("a, b, c, ..." (make-list "enumerate-alpha"))
	    ("A, B, C, ..." (make-list "enumerate-Alpha")))
	((balloon (icon "tm_description.xpm") "Description#(E-D)")
	 (make-list "description"))
	(if (or (inside-list?) (inside-description?))
	    ((balloon (icon "tm_item.xpm") "Insert a new item#(E-N)")
	     (make-item)))
	|)
    (if (style-has? "basic-style")
	;;((balloon
	;;(text (roman rm bold right 12 600) "S")
	;;"Write bold text#(E-C-b)")
	;;(make-with "font series" "bold"))
	((balloon (icon "tm_strong.xpm") "Write strong text#(E-s s)")
	 (make-expand-arg "strong"))
	((balloon (icon "tm_emphasize.xpm") "Emphasize text#(E-s e)")
	 (make-expand-arg "em"))
	((balloon (icon "tm_typewriter.xpm") "Write typewriter text#(E-s t)")
	 (make-expand-arg "tt"))
	((balloon (icon "tm_sansserif.xpm") "Write sample text#(E-s p)")
	 (make-expand-arg "samp"))
	((balloon (icon "tm_name.xpm") "Write a name#(E-s n)")
	 (make-expand-arg "name")))
    (if (not (style-has? "basic-style"))
	((balloon (icon "tm_bold.xpm") "Write bold text#(E-C-b)")
	 (make-with "font series" "bold"))
	((balloon (icon "tm_italic.xpm") "Write italic text#(E-C-i)")
	 (make-with "font shape" "italic"))
	((balloon (icon "tm_typewriter.xpm") "Use a typewriter font#(E-C-t)")
	 (make-with "font family" "tt"))
	((balloon (icon "tm_sansserif.xpm") "Use a sans serif font#(E-C-s)")
	 (make-with "font family" "ss"))
	((balloon (icon "tm_smallcaps.xpm") "Use small capitals#(E-C-p)")
	 (make-with "font shape" "small-caps")))
    (=> (balloon (icon "tm_color.xpm") "Select a foreground color")
      (link color-menu))))

(define texmacs-math-icons
  '(((balloon (icon "tm_fraction.xpm") "Insert a fraction#(E-F)")
      (make-fraction))
    ((balloon (icon "tm_sqrt.xpm") "Insert a square root#(E-S)")
      (make-sqrt))
    ((balloon (icon "tm_root.xpm") "Insert an n-th root#(E-R)")
      (make-var-sqrt))
    ((balloon (icon "tm_sub.xpm") "Make a subscript#(_)")
      (make-script #f #t))
    ((balloon (icon "tm_sup.xpm") "Make a superscript#(^)")
      (make-script #t #t))
    (=> (balloon (icon "tm_hat.xpm") "Insert an accent")
	((icon "tm_hat.xpm") "E-^" (make-wide "^"))
	((icon "tm_tilda.xpm") "E-~" (make-wide "~"))
	((icon "tm_bar.xpm") "E-B" (make-wide "<bar>"))
	((icon "tm_vect.xpm") "E-V" (make-wide "<vect>"))
	((icon "tm_check.xpm") "E-V" (make-wide "<check>"))
	((icon "tm_breve.xpm") "E-U" (make-wide "<breve>"))
	((icon "tm_dot.xpm") "E-." (make-wide "<dot>"))
	((icon "tm_ddot.xpm") "E-\"" (make-wide "<ddot>"))
	((icon "tm_acute.xpm") "E-'" (make-wide "<acute>"))
	((icon "tm_grave.xpm") "E-`" (make-wide "<grave>")))
    |
    (=> (balloon (icon "tm_bigop.xpm") "Insert a big operator")
	(tile 8 (link big-operator-menu)))
    (=> (balloon (icon "tm_bigleft.xpm") "Insert a large left delimiter")
	(tile 8 (link left-delimiter-menu)))
    (=> (balloon (icon "tm_bigsep.xpm") "Insert a large separator")
	(tile 8 (link middle-delimiter-menu)))
    (=> (balloon (icon "tm_bigright.xpm") "Insert a large right delimiter")
	(tile 8 (link right-delimiter-menu)))
    (=> (balloon (icon "tm_greek.xpm") "Insert a greek character")
	(tile 8 (link lower-greek-menu))
	---
	(tile 8 (link upper-greek-menu)))
    (=> (balloon (icon "tm_binop.xpm") "Insert a binary operation")
	(tile 8 (link binary-operation-menu)))
    (=> (balloon (icon "tm_binrel.xpm") "Insert a binary relation")
	(tile 8 (link binary-relation-menu-1))
	---
	(tile 8 (link binary-relation-menu-2)))
    (=> (balloon (icon "tm_arrow.xpm") "Insert an arrow")
	(tile 9 (link horizontal-arrow-menu))
	---
	(tile 8 (link vertical-arrow-menu))
	---
	(tile 6 (link long-arrow-menu)))
    (=> (balloon (icon "tm_miscsymb.xpm") "Insert a miscellaneous symbol")
	(tile 8 (link miscellaneous-symbol-menu))
	---
	(tile 6 (link dots-menu)))
    |
    ((balloon (icon "tm_mathbold.xpm") "Write bold mathematics#(E-C-b)")
      (make-with "math font series" "bold"))
    ((balloon (icon "tm_cal.xpm") "Use a calligraphical font#(E-C-C)")
      (make-with "math font" "cal"))
    ((balloon (icon "tm_frak.xpm") "Use the fraktur font#(E-C-F)")
      (make-with "math font" "Euler"))
    ((balloon (icon "tm_bbb.xpm") "Use the blackboard bold font#(E-C-B)")
      (make-with "math font" "Bbb*"))
    (=> (balloon (icon "tm_color.xpm") "Select a foreground color")
	(link color-menu))))

(define texmacs-prog-icons
  '(((balloon (icon "tm_bold.xpm") "Write bold text#(E-C-b)")
      (make-with "prog font series" "bold"))
    ((balloon (icon "tm_italic.xpm") "Write italic text#(E-C-i)")
      (make-with "prog font shape" "italic"))
    ((balloon (icon "tm_sansserif.xpm") "Use a sans serif font#(E-C-s)")
      (make-with "prog font family" "ss"))
    (=> (balloon (icon "tm_color.xpm") "Select a foreground color")
	(link color-menu))
    |
    ((balloon (icon "tm_stop.xpm") "Interrupt execution")
      (connection-interrupt))
    ((balloon (icon "tm_clsession.xpm") "Close session")
      (connection-stop))
    (if (and (equal? (get-env "prog language") "maxima")
	     (file-exists? "$MAXIMA_DIRECTORY/info" "maxima_toc.html"))
	|
	((balloon (icon "tm_help.xpm") "Maxima manual")
	 (load-html-buffer "$MAXIMA_DIRECTORY/info/maxima_toc.html")))
    (if (and (equal? (get-env "prog language") "reduce")
	     (file-exists? "$reduce/doc/manual" "abstract.tex"))
	|
	(=> (balloon (icon "tm_help.xpm") "Reduce documentation")
	    (link reduce-help-menu)))))

(define texmacs-context-icons
  '((if (equal? (get-env "mode") "text") (link texmacs-text-icons))
    (if (equal? (get-env "mode") "math") (link texmacs-math-icons))
    (if (equal? (get-env "mode") "prog") (link texmacs-prog-icons))))
